﻿Imports System.ComponentModel.DataAnnotations
Imports CSSCustomerEdit.Web.Resources

Namespace CSSCustomerEdit.Web

	''' <summary>
	''' Class containing the values and validation rules for user registration.
	''' </summary>
	Public NotInheritable Partial Class RegistrationData
        ''' <summary>
        ''' Gets and sets the user name.
        ''' </summary>
        <Key(), Required(ErrorMessageResourceName:="ValidationErrorRequiredField", ErrorMessageResourceType:=GetType(ValidationErrorResources)),
        Display(Order:=0, Name:="UserNameLabel", ResourceType:=GetType(RegistrationDataResources)),
        RegularExpression("^[a-zA-Z0-9_]*$",
            ErrorMessageResourceName:="ValidationErrorInvalidUserName",
            ErrorMessageResourceType:=GetType(ValidationErrorResources)),
        StringLength(255, MinimumLength:=4,
            ErrorMessageResourceName:="ValidationErrorBadUserNameLength",
            ErrorMessageResourceType:=GetType(ValidationErrorResources))>
        Public Property UserName() As String

        ''' <summary>
        ''' Gets and sets the email address.
        ''' </summary>
        <Key(), Required(ErrorMessageResourceName:="ValidationErrorRequiredField", ErrorMessageResourceType:=GetType(ValidationErrorResources)),
        Display(Order:=2, Name:="EmailLabel", ResourceType:=GetType(RegistrationDataResources)),
        RegularExpression("^([\w-\.]+)@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.)|(([\w-]+\.)+))([a-zA-Z]{2,4}|[0-9]{1,3})(\]?)$",
            ErrorMessageResourceName:="ValidationErrorInvalidEmail",
            ErrorMessageResourceType:=GetType(ValidationErrorResources))>
        Public Property Email() As String
        ''' <summary>
        ''' Gets and sets the friendly name of the user.
        ''' </summary>
        <Display(Order:=1, Name:="FriendlyNameLabel", Description:="FriendlyNameDescription",
            ResourceType:=GetType(RegistrationDataResources)),
        StringLength(255, MinimumLength:=0, ErrorMessageResourceName:="ValidationErrorBadFriendlyNameLength",
            ErrorMessageResourceType:=GetType(ValidationErrorResources))>
        Public Property FriendlyName As String


        ''' <summary>
        ''' Gets and sets the security question.
        ''' </summary>
        <Required(ErrorMessageResourceName:="ValidationErrorRequiredField",
            ErrorMessageResourceType:=GetType(ValidationErrorResources)),
        Display(Order:=5, Name:="SecurityQuestionLabel", ResourceType:=GetType(RegistrationDataResources))>
        Public Property Question As String

        ''' <summary>
        ''' Gets and sets the answer to the security question.
        ''' </summary>
        <Required(ErrorMessageResourceName:="ValidationErrorRequiredField",
            ErrorMessageResourceType:=GetType(ValidationErrorResources)),
        Display(Order:=6, Name:="SecurityAnswerLabel", ResourceType:=GetType(RegistrationDataResources))>
        Public Property Answer As String
    End Class
End Namespace
