﻿Imports System
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Data

Namespace CSSCustomerEdit

	''' <summary>
	'''     Provides extension methods for performing operations on a <see cref="DataField"/>.
	''' </summary>
	Public Module DataFieldExtensions
		''' <summary>
		''' Replaces a <see cref="DataField" />'s <see cref="TextBox" /> control with another control
		''' and updates the bindings.
		''' </summary>
		''' <param name="field">The <see cref="DataField"/> whose <see cref="TextBox"/> will be replaced.</param>
		''' <param name="newControl">The new control you're going to set as <see cref="DataField.Content" />.</param>
		''' <param name="dataBindingProperty">The control's property that will be used for data binding.</param>        
        <System.Runtime.CompilerServices.Extension()>
        Public Sub ReplaceTextBox(ByVal field As DataField,
                                  ByVal newControl As FrameworkElement,
                                  ByVal dataBindingProperty As DependencyProperty)
            field.ReplaceTextBox(newControl, dataBindingProperty, Sub(binding)
                                                                  End Sub)
        End Sub

        ''' <summary>
        ''' Replaces a <see cref="DataField" />'s <see cref="TextBox" /> control with another control,
        ''' and updates the bindings
        ''' </summary>
        ''' <param name="field">The <see cref="DataField"/> whose <see cref="TextBox"/> will be replaced.</param>
        ''' <param name="newControl">The new control you're going to set as <see cref="DataField.Content" />.</param>
        ''' <param name="dataBindingProperty">The control's property that will be used for data binding.</param>        
        ''' <param name="bindingSetupFunction">
        '''  An optional <see cref="Action"/> you can use to change parameters on the newly generated binding before
        '''  it is applied to <paramref name="newControl"/>
        ''' </param>
        <System.Runtime.CompilerServices.Extension()>
        Public Sub ReplaceTextBox(ByVal field As DataField,
                                  ByVal newControl As FrameworkElement,
                                  ByVal dataBindingProperty As DependencyProperty,
                                  ByVal bindingSetupFunction As Action(Of Binding))
            If field Is Nothing Then
                Throw New ArgumentNullException("field")
            End If

            If newControl Is Nothing Then
                Throw New ArgumentNullException("newControl")
            End If

            ' Construct new binding by copying existing one, and sending it to bindingSetupFunction
            ' for any changes the caller wants to perform
            Dim newBinding = field.Content.GetBindingExpression(TextBox.TextProperty).ParentBinding.CreateCopy()

            If bindingSetupFunction IsNot Nothing Then
                bindingSetupFunction(newBinding)
            End If

            ' Replace field
            newControl.SetBinding(dataBindingProperty, newBinding)
            field.Content = newControl
        End Sub
	End Module
End Namespace
