﻿Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.ServiceModel.DomainServices.Client
Imports System.ServiceModel.DomainServices.Client.ApplicationServices
Imports System.Windows
Imports System.Windows.Controls

Namespace CSSCustomerEdit.LoginUI

	''' <summary>
	''' <see cref="ChildWindow"/> class that controls the registration process.
	''' </summary>
	Partial Public Class LoginRegistrationWindow
		Inherits ChildWindow
		Private possiblyPendingOperations As IList(Of OperationBase) = New List(Of OperationBase)()

		''' <summary>
		''' Creates a new <see cref="LoginRegistrationWindow"/> instance.
		''' </summary>
		Public Sub New()
			InitializeComponent()

			Me.registrationForm.SetParentWindow(Me)
			Me.loginForm.SetParentWindow(Me)

			AddHandler Me.LayoutUpdated, AddressOf GoToInitialState
			AddHandler Me.LayoutUpdated, AddressOf UpdateTitle
		End Sub

		''' <summary>
		''' Initializes the <see cref="VisualStateManager"/> for this component
		''' by putting it into the "AtLogin" state
		''' </summary>
		Private Sub GoToInitialState(ByVal sender As Object, ByVal eventArgs As EventArgs)
			VisualStateManager.GoToState(Me, "AtLogin", False)
			RemoveHandler Me.LayoutUpdated, AddressOf GoToInitialState
		End Sub

		''' <summary>
		''' Updates the window title according to which panel
		''' (registration / login) is currently being displayed
		''' </summary>
		Private Sub UpdateTitle(ByVal sender As Object, ByVal eventArgs As EventArgs)
            Me.Title = If((Me.registrationForm.Visibility = Visibility.Visible),
                          ApplicationStrings.RegistrationWindowTitle,
                          ApplicationStrings.LoginWindowTitle)
		End Sub

		''' <summary>
		''' Notifies the <see cref="LoginRegistrationWindow"/> window that it can only close
		''' if <paramref name="operation"/> is finished or can be cancelled
		''' </summary>
		''' <param name="operation">The pending operation to monitor</param>
		Public Sub AddPendingOperation(ByVal operation As OperationBase)
			Me.possiblyPendingOperations.Add(operation)
		End Sub

		''' <summary>
		''' Causes the <see cref="VisualStateManager"/> to change to the "AtLogin" state.
		''' </summary>
		Public Overridable Sub NavigateToLogin()
			VisualStateManager.GoToState(Me, "AtLogin", True)
		End Sub

		''' <summary>
		''' Causes the <see cref="VisualStateManager"/> to change to the "AtRegistration" state.
		''' </summary>
		Public Overridable Sub NavigateToRegistration()
			VisualStateManager.GoToState(Me, "AtRegistration", True)
		End Sub

		''' <summary>
		''' Prevents the window from closing while there are operations in progress
		''' </summary>
		Private Sub LoginWindow_Closing(ByVal sender As Object, ByVal eventArgs As CancelEventArgs)
            For Each operation In Me.possiblyPendingOperations
                If Not operation.IsComplete Then
                    If operation.CanCancel Then
                        operation.Cancel()
                    Else
                        eventArgs.Cancel = True
                    End If
                End If
            Next operation
		End Sub
	End Class
End Namespace