﻿Imports System.Globalization
Imports System.ServiceModel.DomainServices.Client.ApplicationServices
Imports System.Windows
Imports System.Windows.Controls

Namespace CSSCustomerEdit.LoginUI

	''' <summary>
	''' <see cref="UserControl"/> class that shows the current login status and allows login and logout.
	''' </summary>
	Partial Public Class LoginStatus
        Inherits UserControl
		Private ReadOnly authService As AuthenticationService = WebContext.Current.Authentication

		''' <summary>
		''' Creates a new <see cref="LoginStatus"/> instance.
		''' </summary>
		Public Sub New()
			Me.InitializeComponent()

            Me.welcomeText.SetBinding(TextBlock.TextProperty,
                                      WebContext.Current.CreateOneWayBinding(
                                          "User.DisplayName",
                                          New StringFormatValueConverter(ApplicationStrings.WelcomeMessage)))
			AddHandler Me.authService.LoggedIn, AddressOf Authentication_LoggedIn
			AddHandler Me.authService.LoggedOut, AddressOf Authentication_LoggedOut
			Me.UpdateLoginState()
		End Sub

		Private Sub LoginButton_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
			Dim loginWindow As New LoginRegistrationWindow()
			loginWindow.Show()
		End Sub

        Private Sub LogoutButton_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
            Me.authService.Logout(Sub(logoutOperation)
                                      If logoutOperation.HasError Then
                                          ErrorWindow.CreateNew(logoutOperation.Error)
                                          logoutOperation.MarkErrorAsHandled()
                                      End If
                                  End Sub, Nothing)
        End Sub

        Private Sub Authentication_LoggedIn(ByVal sender As Object, ByVal e As AuthenticationEventArgs)
            Me.UpdateLoginState()
        End Sub

        Private Sub Authentication_LoggedOut(ByVal sender As Object, ByVal e As AuthenticationEventArgs)
            Me.UpdateLoginState()
        End Sub

        Private Sub UpdateLoginState()
            If WebContext.Current.User.IsAuthenticated Then
                VisualStateManager.GoToState(
                    Me, If((TypeOf WebContext.Current.Authentication Is WindowsAuthentication),
                           "windowsAuth", "loggedIn"), True)
            Else
                VisualStateManager.GoToState(Me, "loggedOut", True)
            End If
        End Sub
    End Class
End Namespace
